
import { Inter } from "next/font/google";
import { getApiData } from "@/Helper/common";
import { headers } from 'next/headers';
import Link from "next/link";



const inter = Inter({ subsets: ["latin"] });


// export const dynamic = 'force-dynamic';
export async function generateMetadata({ params }) {

  const headersList = headers(); // `headers` provides access to the headers in Next.js
  var domainWithPort = '';

  try {

    const host = headersList.get('host');

    if (host) {
      domainWithPort = host; // e.g., 'example.com' or 'localhost:3000'
      console.warn("Host header is " + host);

    } else {
      console.warn("Host header is missing.");
      domainWithPort = ''; // Default fallback
    }
  } catch (error) {
    console.error("Error retrieving host header:", error.message);
    domainWithPort = ''; // Default fallback
  }

  // console.log(JSON.stringify(headersList))
  // console.log(`theme-setting/single?domain=${domainWithPort}`)

  const data = await getApiData(`theme-setting/single`, domainWithPort);
  // console.log(data)
  return {
    title: data?.result?.meta_title ?? data?.result?.company_name, // Fallback to a default title
    description: data?.result?.meta_description ?? data?.result?.about, // Fallback to a default description
    keywords: data?.result?.meta_title, // Fallback to default keywords

  };
}


export default async function RootLayout({ children }) {


  return (
    <html lang="en">
      <meta charSet="utf-8" />
      <meta name="viewport" content="width=device-width,initial-scale=1" />
      <meta name="styled-components-container" />
      <script async
        // you might need to get a newer version
        src="https://kit.fontawesome.com/fbadad80a0.js"
        crossOrigin="anonymous"
      ></script>


      <link href="https://fonts.googleapis.com/css2?family=Roboto:ital,wght@0,300;0,400;0,500;0,700;1,400;1,500;1,700&display=swap" rel="stylesheet" />


      <body >





        {children}



      </body>

    </html>
  );
}